import { SupportedLanguagesEnum } from '@energyweb/origin-ui-localization';
import { useTranslation } from 'react-i18next';
import { object, string, ref } from 'yup';
import { UserStatus, KYCStatus, OrganizationStatus } from '@energyweb/origin-backend-react-query-client';
import { PowerFormatter, formatDate } from '@energyweb/origin-ui-utils';
import { Role, KYCStatus as KYCStatus$1, UserStatus as UserStatus$1 } from '@energyweb/origin-backend-core';
import { useNavigate } from 'react-router';
import { HowToReg, AccountCircle, ExitToApp } from '@material-ui/icons';

var prepareLanguageOptions = function prepareLanguageOptions(t) {
  var supportedLanugages = Object.keys(SupportedLanguagesEnum);
  return supportedLanugages.map(function (language) {
    return {
      label: t("user.settings.languages.".concat(language)),
      value: language
    };
  });
};

var useSettingsPageLogic = function useSettingsPageLogic() {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    notificationsLabel: t('user.settings.notifications'),
    languageLabel: t('user.settings.language'),
    languageOptions: prepareLanguageOptions(t),
    buttonText: t('general.buttons.update')
  };
};

var useOrganizationBlockchainAddressLogic = function useOrganizationBlockchainAddressLogic() {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    title: t('user.profile.orgBlockchainAccountAddress'),
    popoverText: [t('user.profile.popover.blockchainWhatIs'), t('user.profile.popover.blockchainWhatFor'), t('user.profile.popover.blockchainHowTo')],
    buttonText: t('user.profile.connectBlockchain')
  };
};

var useExchangeDepositAddressLogic = function useExchangeDepositAddressLogic() {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    title: t('user.profile.exchangeAddressTitle'),
    popoverText: [t('user.profile.popover.exchangeAddressWhatFor'), t('user.profile.popover.exchangeAddressHowTo')],
    buttonText: t('user.profile.createExchangeAddressButton')
  };
};

var useUpdateUserAccountDataFormConfig = function useUpdateUserAccountDataFormConfig(user) {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  var firstName = user.firstName,
      lastName = user.lastName,
      telephone = user.telephone,
      status = user.status,
      kycStatus = user.kycStatus;
  var initialFormData = {
    firstName: firstName,
    lastName: lastName,
    telephone: telephone,
    status: status,
    kycStatus: kycStatus
  };
  return {
    buttonText: t('general.buttons.edit'),
    fields: [{
      label: t('user.profile.firstName'),
      name: 'firstName',
      required: true
    }, {
      label: t('user.profile.lastName'),
      name: 'lastName',
      required: true
    }, {
      label: t('user.profile.telephone'),
      name: 'telephone',
      required: true
    }, {
      label: t('user.profile.status'),
      name: 'status',
      textFieldProps: {
        disabled: true
      }
    }, {
      label: t('user.profile.kycStatus'),
      name: 'kycStatus',
      textFieldProps: {
        disabled: true
      }
    }],
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    initialValues: initialFormData,
    twoColumns: true,
    inputsVariant: 'filled',
    validationSchema: object().shape({
      firstName: string().label(t('user.profile.firstName')).required(),
      lastName: string().label(t('user.profile.lastName')).required(),
      telephone: string().min(10).label(t('user.profile.telephone')).required()
    })
  };
};

var useUpdateUserAccountEmailFormConfig = function useUpdateUserAccountEmailFormConfig(initialValues) {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    buttonText: t('general.buttons.change'),
    fields: [{
      label: t('user.profile.email'),
      name: 'email',
      required: true
    }],
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    initialValues: {
      email: initialValues === null || initialValues === void 0 ? void 0 : initialValues.email
    },
    inputsVariant: 'filled',
    validationSchema: object().shape({
      email: string().email().label(t('user.profile.email')).required()
    })
  };
};

var INITIAL_FORM_VALUES = {
  oldPassword: '',
  newPassword: '',
  newPasswordConfirm: ''
};
var useUpdateUserAccountPasswordFormConfig = function useUpdateUserAccountPasswordFormConfig() {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    buttonText: t('general.buttons.change'),
    fields: [{
      type: 'password',
      label: t('user.profile.currentPassword'),
      name: 'oldPassword',
      required: true
    }, {
      type: 'password',
      label: t('user.profile.newPassword'),
      name: 'newPassword',
      required: true
    }, {
      type: 'password',
      label: t('user.profile.newPasswordConfirm'),
      name: 'newPasswordConfirm',
      required: true
    }],
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    initialValues: INITIAL_FORM_VALUES,
    inputsVariant: 'filled',
    validationSchema: object().shape({
      oldPassword: string().label(t('user.profile.currentPassword')).required(),
      newPassword: string().label(t('user.profile.newPassword')).required(),
      newPasswordConfirm: string().oneOf([ref('newPassword'), null], t('user.profile.confirmDoesntMatch')).label(t('user.profile.confirmPassword')).required()
    })
  };
};

var INITIAL_FORM_VALUES$1 = {
  username: '',
  password: ''
};
var useUserLogInFormConfig = function useUserLogInFormConfig(formSubmitHandler) {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    buttonFullWidth: true,
    buttonText: t('user.login.loginButton'),
    fields: [{
      label: t('user.login.email'),
      name: 'username'
    }, {
      label: t('user.login.password'),
      type: 'password',
      name: 'password'
    }],
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    initialValues: INITIAL_FORM_VALUES$1,
    submitHandler: formSubmitHandler,
    validationMode: 'onTouched',
    inputsVariant: 'filled',
    validationSchema: object().shape({
      username: string().email().label(t('user.login.email')).required(),
      password: string().label(t('user.login.password')).required()
    })
  };
};

var INITIAL_FORM_VALUES$2 = {
  title: '',
  firstName: '',
  lastName: '',
  telephone: '',
  email: '',
  password: ''
};
var TITLES = ['Dr', 'Mr', 'Mrs', 'Ms', 'Other'];
var useUserSignInFormConfig = function useUserSignInFormConfig(formSubmitHandler) {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  var TITLE_OPTIONS = TITLES.map(function (title) {
    return {
      label: t("general.titles.".concat(title.toLowerCase())),
      value: title
    };
  });
  return {
    buttonText: t('general.buttons.register'),
    fields: [{
      label: t('user.register.title'),
      name: 'title',
      select: true,
      options: TITLE_OPTIONS,
      required: true,
      additionalInputProps: {
        valueToOpen: 'Other',
        name: 'titleInput',
        label: t('user.register.title'),
        required: true
      }
    }, {
      label: t('user.register.firstName'),
      name: 'firstName',
      required: true
    }, {
      label: t('user.register.lastName'),
      name: 'lastName',
      required: true
    }, {
      label: t('user.register.email'),
      name: 'email',
      required: true
    }, {
      label: t('user.register.telephone'),
      name: 'telephone',
      required: true
    }, {
      type: 'password',
      label: t('user.register.password'),
      name: 'password',
      required: true
    }],
    twoColumns: true,
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    initialValues: INITIAL_FORM_VALUES$2,
    submitHandler: formSubmitHandler,
    inputsVariant: 'filled',
    validationSchema: object().shape({
      title: string().label(t('user.register.title')).required(),
      firstName: string().label(t('user.register.firstName')).required(),
      lastName: string().label(t('user.register.lastName')).required(),
      email: string().email().label(t('user.register.email')).required(),
      telephone: string().min(10).label(t('user.register.telephone')).required(),
      password: string().min(6).label(t('user.register.password')).required()
    })
  };
};

var prepareUsersData = function prepareUsersData(user, actions) {
  var _a;

  return {
    id: user.id,
    name: "".concat(user.firstName, " ").concat(user.lastName),
    organization: (_a = user.organization) === null || _a === void 0 ? void 0 : _a.name,
    email: user.email,
    status: user.status,
    kycStatus: user.kycStatus,
    actions: actions
  };
};

var useAdminUsersTableLogic = function useAdminUsersTableLogic(users, actions, loading) {
  var _a;

  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    header: {
      name: t('admin.users.name'),
      organization: t('admin.users.organization'),
      email: t('admin.users.email'),
      status: t('admin.users.status'),
      kycStatus: t('admin.users.kycStatus'),
      actions: ''
    },
    loading: loading,
    pageSize: 25,
    data: (_a = users === null || users === void 0 ? void 0 : users.map(function (user) {
      return prepareUsersData(user, actions);
    })) !== null && _a !== void 0 ? _a : []
  };
};

var STATUS_OPTIONS = Object.keys(UserStatus).map(function (key) {
  return {
    value: key,
    label: key
  };
});
var KYC_STATUS_OPTIONS = Object.keys(KYCStatus).map(function (key) {
  return {
    value: key,
    label: key
  };
});

var useAdminUpdateUserFormLogic = function useAdminUpdateUserFormLogic(user) {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  var initialFormData = {
    title: user === null || user === void 0 ? void 0 : user.title,
    firstName: user === null || user === void 0 ? void 0 : user.firstName,
    lastName: user === null || user === void 0 ? void 0 : user.lastName,
    email: user === null || user === void 0 ? void 0 : user.email,
    telephone: user === null || user === void 0 ? void 0 : user.telephone,
    status: user === null || user === void 0 ? void 0 : user.status,
    kycStatus: user === null || user === void 0 ? void 0 : user.kycStatus
  };
  return {
    buttonText: t('general.buttons.update'),
    fields: [{
      label: t('admin.updateUser.title'),
      name: 'title'
    }, {
      label: t('admin.updateUser.firstName'),
      name: 'firstName'
    }, {
      label: t('admin.updateUser.lastName'),
      name: 'lastName'
    }, {
      label: t('admin.updateUser.email'),
      name: 'email'
    }, {
      label: t('admin.updateUser.telephone'),
      name: 'telephone'
    }, {
      label: t('admin.updateUser.status'),
      name: 'status',
      select: true,
      options: STATUS_OPTIONS
    }, {
      label: t('admin.updateUser.kycStatus'),
      name: 'kycStatus',
      select: true,
      options: KYC_STATUS_OPTIONS
    }],
    buttonWrapperProps: {
      justifyContent: 'flex-start'
    },
    initialValues: initialFormData,
    twoColumns: true,
    inputsVariant: 'filled',
    validationSchema: object().shape({
      firstName: string().label(t('admin.updateUser.firstName')).required(),
      lastName: string().label(t('admin.updateUser.lastName')).required(),
      email: string().email().label(t('admin.updateUser.email')).required(),
      telephone: string().label(t('admin.updateUser.telephone')).required()
    })
  };
};

var formatClaims = function formatClaims(_ref) {
  var certificates = _ref.certificates,
      allDevices = _ref.allDevices;
  var formattedClaims = [];
  certificates === null || certificates === void 0 ? void 0 : certificates.forEach(function (certificate) {
    var _a;

    return (_a = certificate.claims) === null || _a === void 0 ? void 0 : _a.forEach(function (claim) {
      var _a;

      formattedClaims.push({
        id: "".concat(certificate.id, ";").concat(claim.claimData.periodStartDate),
        certificateId: certificate.id,
        deviceName: (_a = allDevices.find(function (device) {
          return device.externalRegistryId === certificate.deviceId;
        })) === null || _a === void 0 ? void 0 : _a.name,
        energy: PowerFormatter.format(parseInt(claim.value), true),
        beneficiary: claim.claimData.beneficiary,
        fromDate: formatDate(claim.claimData.periodStartDate),
        toDate: formatDate(claim.claimData.periodEndDate)
      });
    });
  });
  return formattedClaims;
};

var useClaimsTableLogic = function useClaimsTableLogic(_ref2) {
  var isLoading = _ref2.isLoading,
      certificates = _ref2.certificates,
      allDevices = _ref2.allDevices;

  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    header: {
      certificateId: t('admin.claims.certificateId'),
      deviceName: t('admin.claims.deviceName'),
      energy: t('admin.claims.energy'),
      beneficiary: t('admin.claims.beneficiary'),
      fromDate: t('admin.claims.fromDate'),
      toDate: t('admin.claims.toDate')
    },
    pageSize: 10,
    loading: isLoading,
    data: formatClaims({
      certificates: certificates,
      allDevices: allDevices
    })
  };
};

var getAccountMenu = function getAccountMenu(_ref) {
  var t = _ref.t,
      isOpen = _ref.isOpen,
      showSettings = _ref.showSettings,
      showUserProfile = _ref.showUserProfile;
  return {
    isOpen: isOpen,
    sectionTitle: showUserProfile ? t('navigation.account.sectionTitle') : t('navigation.account.sectionTitleForUnlogged'),
    rootUrl: 'account',
    show: true,
    menuList: [{
      url: 'settings',
      label: t('navigation.account.settings'),
      show: showSettings
    }, {
      url: 'profile',
      label: t('navigation.account.userProfile'),
      show: showUserProfile
    }]
  };
};

var getAdminMenu = function getAdminMenu(_ref) {
  var t = _ref.t,
      isOpen = _ref.isOpen,
      showSection = _ref.showSection,
      showUsers = _ref.showUsers,
      showClaims = _ref.showClaims;
  return {
    isOpen: isOpen,
    sectionTitle: t('navigation.admin.sectionTitle'),
    rootUrl: 'admin',
    show: showSection,
    menuList: [{
      url: 'users',
      label: t('navigation.admin.users'),
      show: showUsers
    }, {
      url: 'claims',
      label: t('navigation.admin.claims'),
      show: showClaims
    }]
  };
};

var useUserRegisteredModalLogic = function useUserRegisteredModalLogic(closeModal) {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    title: t('user.modals.userRegistered.title'),
    text: t('user.modals.userRegistered.text'),
    buttons: [{
      label: t('general.buttons.ok'),
      onClick: closeModal
    }]
  };
};

var useLoginRegisterOrgModalLogic = function useLoginRegisterOrgModalLogic(closeModal, navigateToRegister) {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    title: t('user.modals.loginRegisterOrg.title'),
    text: t('user.modals.loginRegisterOrg.text'),
    buttons: [{
      label: t('general.buttons.notNow'),
      onClick: closeModal
    }, {
      label: t('user.modals.loginRegisterOrg.registerOrgButton'),
      onClick: navigateToRegister
    }]
  };
};

var roleNames = [{
  value: Role.OrganizationAdmin,
  label: 'user.modals.roleOrgAdmin'
}, {
  value: Role.OrganizationDeviceManager,
  label: 'user.modals.roleOrgDeviceManager'
}, {
  value: Role.OrganizationUser,
  label: 'user.modals.roleOrgMember'
}];
var usePendingInvitationModalLogic = function usePendingInvitationModalLogic(_ref) {
  var invitation = _ref.invitation,
      acceptHandler = _ref.acceptHandler,
      declineHandler = _ref.declineHandler,
      laterHandler = _ref.laterHandler;

  var _a;

  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    title: t('user.modals.pendingInvitation.title'),
    text: t('user.modals.pendingInvitation.text', {
      admin: invitation === null || invitation === void 0 ? void 0 : invitation.sender,
      role: t((_a = roleNames.find(function (role) {
        return role.value === (invitation === null || invitation === void 0 ? void 0 : invitation.role);
      })) === null || _a === void 0 ? void 0 : _a.label),
      orgName: invitation === null || invitation === void 0 ? void 0 : invitation.organization.name
    }),
    buttons: [{
      label: t('general.buttons.later'),
      onClick: function onClick() {
        return laterHandler(invitation.id);
      }
    }, {
      label: t('general.buttons.decline'),
      onClick: function onClick() {
        return declineHandler(invitation.id);
      }
    }, {
      label: t('general.buttons.accept'),
      onClick: function onClick() {
        return acceptHandler(invitation.id);
      }
    }]
  };
};

var useCreateExchangeAddressModalLogic = function useCreateExchangeAddressModalLogic(closeModal, navigateToCreate) {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    title: t('user.modals.createExchangeAddress.title'),
    text: t('user.modals.createExchangeAddress.text'),
    buttons: [{
      label: t('general.buttons.notNow'),
      onClick: closeModal
    }, {
      label: t('user.modals.createExchangeAddress.create'),
      onClick: navigateToCreate
    }]
  };
};

var getRoleChangedLogic = function getRoleChangedLogic(_ref) {
  var t = _ref.t,
      closeModal = _ref.closeModal,
      role = _ref.role,
      orgName = _ref.orgName,
      isIRecEnabled = _ref.isIRecEnabled;

  var memberActions = function memberActions(isMainRole) {
    return {
      title: isMainRole ? t('organization.modals.roleChanged.asMemberYouCan') : t('organization.modals.roleChanged.asAMemberYouCanAlso'),
      actions: [t('organization.modals.roleChanged.canPlaceOrder'), t('organization.modals.roleChanged.canBuyCertificates', {
        certificateType: isIRecEnabled ? 'I-RECs' : 'certificates'
      }), t('organization.modals.roleChanged.canCreateAndBuyCertificateBundles', {
        certificateType: isIRecEnabled ? 'I-REC' : 'certificate'
      }), t('organization.modals.roleChanged.canRedeemCertificates', {
        certificateType: isIRecEnabled ? 'I-RECs' : 'certificates'
      }), t('organization.modals.roleChanged.canWithdrawCertificates', {
        certificateType: isIRecEnabled ? 'I-RECs' : 'certificates'
      })]
    };
  };

  var deviceManagerActions = function deviceManagerActions(isMainRole) {
    return {
      title: isMainRole ? t('organization.modals.roleChanged.asDeviceManagerYouCan') : t('organization.modals.roleChanged.asDeviceManagerYouCanAlso'),
      actions: [t('organization.modals.roleChanged.canRegisterDevices'), t('organization.modals.roleChanged.canRequestIssuenceOfCertificates', {
        certificateType: isIRecEnabled ? 'I-RECs' : 'certificates'
      }), t('organization.modals.roleChanged.canConfigureAutomatedOrderCreation')]
    };
  };

  var orgAdminActions = {
    title: t('organization.modals.roleChanged.asOrgAdminYouCan'),
    actions: [t('organization.modals.roleChanged.canAddOrRemoveOrgMembers'), t('organization.modals.roleChanged.canEditUserRoles'), isIRecEnabled && t('organization.modals.roleChanged.connectOrgToIRec')]
  };
  var roleDescriptions = role === Role.OrganizationUser ? [memberActions(true)] : role === Role.OrganizationDeviceManager ? [deviceManagerActions(true), memberActions(false)] : role === Role.OrganizationAdmin ? [orgAdminActions, deviceManagerActions(false), memberActions(false)] : [];
  return {
    title: t('organization.modals.roleChanged.title', {
      organizationName: orgName
    }),
    subtitle: t('organization.modals.roleChanged.text', {
      organizationName: orgName
    }),
    roleDescriptions: roleDescriptions,
    buttons: [{
      label: 'Ok',
      onClick: closeModal
    }]
  };
};

var useTopbarButtonList = function useTopbarButtonList(isAuthenticated, onLogout) {
  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  var navigate = useNavigate();
  return [{
    label: t('navigation.topbar.register'),
    show: !isAuthenticated,
    onClick: function onClick() {
      navigate('/auth/register');
    },
    Icon: HowToReg
  }, {
    label: t('navigation.topbar.login'),
    show: !isAuthenticated,
    onClick: function onClick() {
      navigate('/login');
    },
    Icon: AccountCircle
  }, {
    label: t('navigation.topbar.logout'),
    show: isAuthenticated,
    onClick: onLogout,
    Icon: ExitToApp
  }];
};

var useUserAndOrgData = function useUserAndOrgData(user) {
  var _a;

  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  return {
    userData: {
      username: "".concat(user === null || user === void 0 ? void 0 : user.firstName, " ").concat(user === null || user === void 0 ? void 0 : user.lastName),
      userPending: (user === null || user === void 0 ? void 0 : user.kycStatus) === KYCStatus$1.Pending || (user === null || user === void 0 ? void 0 : user.status) === UserStatus$1.Pending,
      userTooltip: t('navigation.layout.userPendingTooltip')
    },
    orgData: {
      orgName: (_a = user === null || user === void 0 ? void 0 : user.organization) === null || _a === void 0 ? void 0 : _a.name,
      orgPending: (user === null || user === void 0 ? void 0 : user.organization) && user.organization.status !== OrganizationStatus.Active,
      orgTooltip: t('navigation.layout.orgPendingTooltip')
    }
  };
};

export { INITIAL_FORM_VALUES$1 as INITIAL_FORM_VALUES, getAccountMenu, getAdminMenu, getRoleChangedLogic, roleNames, useAdminUpdateUserFormLogic, useAdminUsersTableLogic, useClaimsTableLogic, useCreateExchangeAddressModalLogic, useExchangeDepositAddressLogic, useLoginRegisterOrgModalLogic, useOrganizationBlockchainAddressLogic, usePendingInvitationModalLogic, useSettingsPageLogic, useTopbarButtonList, useUpdateUserAccountDataFormConfig, useUpdateUserAccountEmailFormConfig, useUpdateUserAccountPasswordFormConfig, useUserAndOrgData, useUserLogInFormConfig, useUserRegisteredModalLogic, useUserSignInFormConfig };
